
from operator import attrgetter
import pyangbind.lib.xpathhelper as xpathhelper
from pyangbind.lib.yangtypes import RestrictedPrecisionDecimalType, RestrictedClassType, TypedListType
from pyangbind.lib.yangtypes import YANGBool, YANGListType, YANGDynClass, ReferenceType
from pyangbind.lib.base import PybindBase
from decimal import Decimal
from bitarray import bitarray
class received(PybindBase):
  """
  This class was auto-generated by the PythonClass plugin for PYANG
  from YANG module openconfig-bgp - based on the path /bgp/neighbors/neighbor/state/messages/received. Each member element of
  the container is represented as a class variable - with a specific
  YANG type.

  YANG Description: Counters for BGP messages received from the neighbor
  """
  __slots__ = ('_pybind_generated_by', '_path_helper', '_yang_name', '_extmethods', '__UPDATE','__NOTIFICATION',)

  _yang_name = 'received'

  _pybind_generated_by = 'container'

  def __init__(self, *args, **kwargs):

    helper = kwargs.pop("path_helper", None)
    if helper is False:
      self._path_helper = False
    elif helper is not None and isinstance(helper, xpathhelper.YANGPathHelper):
      self._path_helper = helper
    elif hasattr(self, "_parent"):
      helper = getattr(self._parent, "_path_helper", False)
      self._path_helper = helper
    else:
      self._path_helper = False

    self._extmethods = False
    self.__NOTIFICATION = YANGDynClass(base=RestrictedClassType(base_type=long, restriction_dict={'range':  ['0..18446744073709551615']}, int_size=64), is_leaf=True, yang_name="NOTIFICATION", parent=self, path_helper=self._path_helper, extmethods=self._extmethods, register_paths=True, namespace='http://openconfig.net/yang/bgp', defining_module='openconfig-bgp', yang_type='uint64', is_config=False)
    self.__UPDATE = YANGDynClass(base=RestrictedClassType(base_type=long, restriction_dict={'range':  ['0..18446744073709551615']}, int_size=64), is_leaf=True, yang_name="UPDATE", parent=self, path_helper=self._path_helper, extmethods=self._extmethods, register_paths=True, namespace='http://openconfig.net/yang/bgp', defining_module='openconfig-bgp', yang_type='uint64', is_config=False)

    load = kwargs.pop("load", None)
    if args:
      if len(args) > 1:
        raise TypeError("cannot create a YANG container with >1 argument")
      all_attr = True
      for e in self._pyangbind_elements:
        if not hasattr(args[0], e):
          all_attr = False
          break
      if not all_attr:
        raise ValueError("Supplied object did not have the correct attributes")
      for e in self._pyangbind_elements:
        nobj = getattr(args[0], e)
        if nobj._changed() is False:
          continue
        setmethod = getattr(self, "_set_%s" % e)
        if load is None:
          setmethod(getattr(args[0], e))
        else:
          setmethod(getattr(args[0], e), load=load)

  def _path(self):
    if hasattr(self, "_parent"):
      return self._parent._path()+[self._yang_name]
    else:
      return [u'bgp', u'neighbors', u'neighbor', u'state', u'messages', u'received']

  def _get_UPDATE(self):
    """
    Getter method for UPDATE, mapped from YANG variable /bgp/neighbors/neighbor/state/messages/received/UPDATE (uint64)

    YANG Description: Number of BGP UPDATE messages announcing, withdrawing
or modifying paths exchanged.
    """
    return self.__UPDATE
      
  def _set_UPDATE(self, v, load=False):
    """
    Setter method for UPDATE, mapped from YANG variable /bgp/neighbors/neighbor/state/messages/received/UPDATE (uint64)
    If this variable is read-only (config: false) in the
    source YANG file, then _set_UPDATE is considered as a private
    method. Backends looking to populate this variable should
    do so via calling thisObj._set_UPDATE() directly.

    YANG Description: Number of BGP UPDATE messages announcing, withdrawing
or modifying paths exchanged.
    """
    try:
      t = YANGDynClass(v,base=RestrictedClassType(base_type=long, restriction_dict={'range':  ['0..18446744073709551615']}, int_size=64), is_leaf=True, yang_name="UPDATE", parent=self, path_helper=self._path_helper, extmethods=self._extmethods, register_paths=True, namespace='http://openconfig.net/yang/bgp', defining_module='openconfig-bgp', yang_type='uint64', is_config=False)
    except (TypeError, ValueError):
      raise ValueError({
          'error-string': """UPDATE must be of a type compatible with uint64""",
          'defined-type': "uint64",
          'generated-type': """YANGDynClass(base=RestrictedClassType(base_type=long, restriction_dict={'range':  ['0..18446744073709551615']}, int_size=64), is_leaf=True, yang_name="UPDATE", parent=self, path_helper=self._path_helper, extmethods=self._extmethods, register_paths=True, namespace='http://openconfig.net/yang/bgp', defining_module='openconfig-bgp', yang_type='uint64', is_config=False)""",
        })

    self.__UPDATE = t
    if hasattr(self, '_set'):
      self._set()

  def _unset_UPDATE(self):
    self.__UPDATE = YANGDynClass(base=RestrictedClassType(base_type=long, restriction_dict={'range':  ['0..18446744073709551615']}, int_size=64), is_leaf=True, yang_name="UPDATE", parent=self, path_helper=self._path_helper, extmethods=self._extmethods, register_paths=True, namespace='http://openconfig.net/yang/bgp', defining_module='openconfig-bgp', yang_type='uint64', is_config=False)


  def _get_NOTIFICATION(self):
    """
    Getter method for NOTIFICATION, mapped from YANG variable /bgp/neighbors/neighbor/state/messages/received/NOTIFICATION (uint64)

    YANG Description: Number of BGP NOTIFICATION messages indicating an
error condition has occurred exchanged.
    """
    return self.__NOTIFICATION
      
  def _set_NOTIFICATION(self, v, load=False):
    """
    Setter method for NOTIFICATION, mapped from YANG variable /bgp/neighbors/neighbor/state/messages/received/NOTIFICATION (uint64)
    If this variable is read-only (config: false) in the
    source YANG file, then _set_NOTIFICATION is considered as a private
    method. Backends looking to populate this variable should
    do so via calling thisObj._set_NOTIFICATION() directly.

    YANG Description: Number of BGP NOTIFICATION messages indicating an
error condition has occurred exchanged.
    """
    try:
      t = YANGDynClass(v,base=RestrictedClassType(base_type=long, restriction_dict={'range':  ['0..18446744073709551615']}, int_size=64), is_leaf=True, yang_name="NOTIFICATION", parent=self, path_helper=self._path_helper, extmethods=self._extmethods, register_paths=True, namespace='http://openconfig.net/yang/bgp', defining_module='openconfig-bgp', yang_type='uint64', is_config=False)
    except (TypeError, ValueError):
      raise ValueError({
          'error-string': """NOTIFICATION must be of a type compatible with uint64""",
          'defined-type': "uint64",
          'generated-type': """YANGDynClass(base=RestrictedClassType(base_type=long, restriction_dict={'range':  ['0..18446744073709551615']}, int_size=64), is_leaf=True, yang_name="NOTIFICATION", parent=self, path_helper=self._path_helper, extmethods=self._extmethods, register_paths=True, namespace='http://openconfig.net/yang/bgp', defining_module='openconfig-bgp', yang_type='uint64', is_config=False)""",
        })

    self.__NOTIFICATION = t
    if hasattr(self, '_set'):
      self._set()

  def _unset_NOTIFICATION(self):
    self.__NOTIFICATION = YANGDynClass(base=RestrictedClassType(base_type=long, restriction_dict={'range':  ['0..18446744073709551615']}, int_size=64), is_leaf=True, yang_name="NOTIFICATION", parent=self, path_helper=self._path_helper, extmethods=self._extmethods, register_paths=True, namespace='http://openconfig.net/yang/bgp', defining_module='openconfig-bgp', yang_type='uint64', is_config=False)

  UPDATE = property(_get_UPDATE)
  NOTIFICATION = property(_get_NOTIFICATION)


  _pyangbind_elements = {'UPDATE': UPDATE, 'NOTIFICATION': NOTIFICATION, }


