
from operator import attrgetter
import pyangbind.lib.xpathhelper as xpathhelper
from pyangbind.lib.yangtypes import RestrictedPrecisionDecimalType, RestrictedClassType, TypedListType
from pyangbind.lib.yangtypes import YANGBool, YANGListType, YANGDynClass, ReferenceType
from pyangbind.lib.base import PybindBase
from decimal import Decimal
from bitarray import bitarray
class state(PybindBase):
  """
  This class was auto-generated by the PythonClass plugin for PYANG
  from YANG module openconfig-routing-policy - based on the path /routing-policy/policy-definitions/policy-definition/statements/statement/actions/state. Each member element of
  the container is represented as a class variable - with a specific
  YANG type.

  YANG Description: Operational state data for policy actions
  """
  __slots__ = ('_pybind_generated_by', '_path_helper', '_yang_name', '_extmethods', '__accept_route','__reject_route',)

  _yang_name = 'state'

  _pybind_generated_by = 'container'

  def __init__(self, *args, **kwargs):

    helper = kwargs.pop("path_helper", None)
    if helper is False:
      self._path_helper = False
    elif helper is not None and isinstance(helper, xpathhelper.YANGPathHelper):
      self._path_helper = helper
    elif hasattr(self, "_parent"):
      helper = getattr(self._parent, "_path_helper", False)
      self._path_helper = helper
    else:
      self._path_helper = False

    self._extmethods = False
    self.__accept_route = YANGDynClass(base=YANGBool, is_leaf=True, yang_name="accept-route", parent=self, choice=(u'route-disposition', u'accept-route'), path_helper=self._path_helper, extmethods=self._extmethods, register_paths=True, namespace='http://openconfig.net/yang/routing-policy', defining_module='openconfig-routing-policy', yang_type='empty', is_config=False)
    self.__reject_route = YANGDynClass(base=YANGBool, is_leaf=True, yang_name="reject-route", parent=self, choice=(u'route-disposition', u'reject-route'), path_helper=self._path_helper, extmethods=self._extmethods, register_paths=True, namespace='http://openconfig.net/yang/routing-policy', defining_module='openconfig-routing-policy', yang_type='empty', is_config=False)

    load = kwargs.pop("load", None)
    if args:
      if len(args) > 1:
        raise TypeError("cannot create a YANG container with >1 argument")
      all_attr = True
      for e in self._pyangbind_elements:
        if not hasattr(args[0], e):
          all_attr = False
          break
      if not all_attr:
        raise ValueError("Supplied object did not have the correct attributes")
      for e in self._pyangbind_elements:
        nobj = getattr(args[0], e)
        if nobj._changed() is False:
          continue
        setmethod = getattr(self, "_set_%s" % e)
        if load is None:
          setmethod(getattr(args[0], e))
        else:
          setmethod(getattr(args[0], e), load=load)

  def _path(self):
    if hasattr(self, "_parent"):
      return self._parent._path()+[self._yang_name]
    else:
      return [u'routing-policy', u'policy-definitions', u'policy-definition', u'statements', u'statement', u'actions', u'state']

  def _get_accept_route(self):
    """
    Getter method for accept_route, mapped from YANG variable /routing_policy/policy_definitions/policy_definition/statements/statement/actions/state/accept_route (empty)

    YANG Description: accepts the route into the routing table
    """
    return self.__accept_route
      
  def _set_accept_route(self, v, load=False):
    """
    Setter method for accept_route, mapped from YANG variable /routing_policy/policy_definitions/policy_definition/statements/statement/actions/state/accept_route (empty)
    If this variable is read-only (config: false) in the
    source YANG file, then _set_accept_route is considered as a private
    method. Backends looking to populate this variable should
    do so via calling thisObj._set_accept_route() directly.

    YANG Description: accepts the route into the routing table
    """
    try:
      t = YANGDynClass(v,base=YANGBool, is_leaf=True, yang_name="accept-route", parent=self, choice=(u'route-disposition', u'accept-route'), path_helper=self._path_helper, extmethods=self._extmethods, register_paths=True, namespace='http://openconfig.net/yang/routing-policy', defining_module='openconfig-routing-policy', yang_type='empty', is_config=False)
    except (TypeError, ValueError):
      raise ValueError({
          'error-string': """accept_route must be of a type compatible with empty""",
          'defined-type': "empty",
          'generated-type': """YANGDynClass(base=YANGBool, is_leaf=True, yang_name="accept-route", parent=self, choice=(u'route-disposition', u'accept-route'), path_helper=self._path_helper, extmethods=self._extmethods, register_paths=True, namespace='http://openconfig.net/yang/routing-policy', defining_module='openconfig-routing-policy', yang_type='empty', is_config=False)""",
        })

    self.__accept_route = t
    if hasattr(self, '_set'):
      self._set()

  def _unset_accept_route(self):
    self.__accept_route = YANGDynClass(base=YANGBool, is_leaf=True, yang_name="accept-route", parent=self, choice=(u'route-disposition', u'accept-route'), path_helper=self._path_helper, extmethods=self._extmethods, register_paths=True, namespace='http://openconfig.net/yang/routing-policy', defining_module='openconfig-routing-policy', yang_type='empty', is_config=False)


  def _get_reject_route(self):
    """
    Getter method for reject_route, mapped from YANG variable /routing_policy/policy_definitions/policy_definition/statements/statement/actions/state/reject_route (empty)

    YANG Description: rejects the route
    """
    return self.__reject_route
      
  def _set_reject_route(self, v, load=False):
    """
    Setter method for reject_route, mapped from YANG variable /routing_policy/policy_definitions/policy_definition/statements/statement/actions/state/reject_route (empty)
    If this variable is read-only (config: false) in the
    source YANG file, then _set_reject_route is considered as a private
    method. Backends looking to populate this variable should
    do so via calling thisObj._set_reject_route() directly.

    YANG Description: rejects the route
    """
    try:
      t = YANGDynClass(v,base=YANGBool, is_leaf=True, yang_name="reject-route", parent=self, choice=(u'route-disposition', u'reject-route'), path_helper=self._path_helper, extmethods=self._extmethods, register_paths=True, namespace='http://openconfig.net/yang/routing-policy', defining_module='openconfig-routing-policy', yang_type='empty', is_config=False)
    except (TypeError, ValueError):
      raise ValueError({
          'error-string': """reject_route must be of a type compatible with empty""",
          'defined-type': "empty",
          'generated-type': """YANGDynClass(base=YANGBool, is_leaf=True, yang_name="reject-route", parent=self, choice=(u'route-disposition', u'reject-route'), path_helper=self._path_helper, extmethods=self._extmethods, register_paths=True, namespace='http://openconfig.net/yang/routing-policy', defining_module='openconfig-routing-policy', yang_type='empty', is_config=False)""",
        })

    self.__reject_route = t
    if hasattr(self, '_set'):
      self._set()

  def _unset_reject_route(self):
    self.__reject_route = YANGDynClass(base=YANGBool, is_leaf=True, yang_name="reject-route", parent=self, choice=(u'route-disposition', u'reject-route'), path_helper=self._path_helper, extmethods=self._extmethods, register_paths=True, namespace='http://openconfig.net/yang/routing-policy', defining_module='openconfig-routing-policy', yang_type='empty', is_config=False)

  accept_route = property(_get_accept_route)
  reject_route = property(_get_reject_route)

  __choices__ = {u'route-disposition': {u'accept-route': [u'accept_route'], u'reject-route': [u'reject_route']}}
  _pyangbind_elements = {'accept_route': accept_route, 'reject_route': reject_route, }


